@@ -24,8 +24,8 @@ class Cci(SimpleIndicator):
             _cci = Cci()
             for t in range(0, len(time_periods)):
                 _time_period = time_periods[t]
-                _np_cci_Array = _cci_tmp_dict[_time_period]
-                _cci_value = _np_cci_Array[_index]
+                _np_cci_array = _cci_tmp_dict[_time_period]
+                _cci_value = _np_cci_array[_index]
 
                 if _cci_value is not None:
                     _cci.setValue(_cci_value, _time_period)
