@@ -18,7 +18,7 @@ class Ma(SimpleIndicator):
             _time_period = time_periods[_t]
             _ma_dict[_time_period] = ta.MA(np_closing_price_array, timeperiod=_time_period, matype=0)
 
-        _ma_array = []
+        _ma_list = []
         for _index in range(0, len(np_closing_price_array)):
             _ma = Ma()
             for t in range(0, len(time_periods)):
@@ -30,6 +30,6 @@ class Ma(SimpleIndicator):
                     _ma.setValue(_v, _time_period)
                 else:
                     _ma.setValue(None, _time_period)
-            _ma_array.append(_ma)
+            _ma_list.append(_ma)
 
-        return _ma_array
+        return _ma_list
