@@ -18,9 +18,8 @@ class Rsi(SimpleIndicator):
 
             _rsi_tmp_dict[_time_period] = ta.RSI(np_closing_price_array, timeperiod=_time_period)
 
-        _rsi_array = []
+        _rsi_list = []
         for _index in range(0, len(np_closing_price_array)):
-
             _rsi = Rsi()
             for _t in range(0, len(time_periods)):
                 _time_period = time_periods[_t]
@@ -31,6 +30,6 @@ class Rsi(SimpleIndicator):
                     _rsi.setValue(_rsi_value, _time_period)
                 else:
                     _rsi.setValue(None, _time_period)
-            _rsi_array.append(_rsi)
+            _rsi_list.append(_rsi)
 
-        return _rsi_array
+        return _rsi_list
